@@ -23,6 +23,10 @@
 
 #include <string.h>
 
+#define WEBKIT_DOM_USE_UNSTABLE_API
+#include <webkitdom/WebKitDOMElementUnstable.h>
+#include <webkitdom/WebKitDOMDOMTokenList.h>
+
 struct _EphyWebOverviewPrivate
 {
   WebKitWebPage *web_page;
@@ -559,6 +563,5 @@ ephy_web_overview_init_js (EphyWebOverview *overview,
   str = JSStringCreateWithUTF8CString ("Overview");
   JSObjectSetProperty (context, global_object, str, class_object, kJSPropertyAttributeNone, NULL);
   JSStringRelease (str);
-
-  /* FIXME: check leaks here */
+  JSClassRelease (class_def);
 }
